# Exercise of Udacity AWS class

Part of [Udacity AWS class 2020][class_url], which is for exercise propose only.

[class_url]: https://www.udacity.com/scholarships/aws-machine-learning-scholarship-program